/*
   Copyright 2011-2014 ALT Linux
   Copyright 2011-2014 Michael Pozhidaev

   This file is part of the Deepsolver.

   Deepsolver is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   Deepsolver is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
*/

#ifndef DEEPSOLVER_H
#define DEEPSOLVER_H

#include"deepsolver/system.h"
#include"deepsolver/config.h"
#include"deepsolver/logging.h"
#include"deepsolver/exceptions.h"
#include"deepsolver/File.h"
#include"deepsolver/Directory.h"
#include"deepsolver/Process.h"
#include"deepsolver/StringUtils.h"
#include"deepsolver/types.h"
#include"deepsolver/Pkg.h"
#include"deepsolver/utils.h"

#define DEEPSOLVER_BEGIN_NAMESPACE namespace Deepsolver {
#define DEEPSOLVER_END_NAMESPACE }

#endif //DEEPSOLVER_H
